<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE xsl:stylesheet>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output xmlns="http://www.w3.org/TR/xhtml1/strict" doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" encoding="utf-8" indent="yes" method="html" omit-xml-declaration="no" version="1.0" media-type="text/xml"/>

	<!-- МагазинКаталогТоваровПоследниеПросмотренные, основан на шаблоне МагазинКаталогТоваровНаГлавнойСпецПред -->

	<!--Создадим ключ по идентификатору товара, чтобы оптимизировать выборку товаров при показе из в обратном хронологическом порядке-->
	<xsl:key name="items_id" match="/shop/item" use="@id"/>

	<!-- Шаблон для магазина -->
	<xsl:template match="/shop">

		<!-- Если есть товары -->
		<xsl:if test="item">

			<h2>Последние просмотренные товары</h2>
			

			<xsl:choose>

				<!--Если в XML существуют узлы, описывающие порядок показа товаров-->
				<xsl:when test="visit_order/last_item/node()">

					<!--то запустим цикл по этим узлам-->
					<xsl:for-each select="visit_order/last_item">

						<!--и для каждого id товара будем вызывать темплейт item, передавая в него узел соответствующего товара, выбранный с помощью ключа-->
						<xsl:apply-templates select="key('items_id', .)"/>

					</xsl:for-each>

				</xsl:when>

				<!--а в случае рандомного показа просто вызовем темплейт item для всех товаров описанных в XML-->
				<xsl:otherwise>
					<xsl:apply-templates select="item"/>
				</xsl:otherwise>

			</xsl:choose>

		</xsl:if>

	</xsl:template>

	<!-- Шаблон для товара -->
	<xsl:template match="item">
		<div class="shop_item">
			<div class="left" style="text-align: center; position: relative;">
				<!-- Указана малое изображение -->
				<xsl:if test="small_image != ''">
					<a href="{/shop/path}{fullpath}{path}/">
						<img src="{small_image}" alt="{name}" title="{name}"/>
					</a>
					<div class="hit" style="margin: {small_image/@height - 35}px 0 0 90px;"></div>
				</xsl:if>

				<!-- Ссылка на товар -->
				<p>
					<a href="{/shop/path}{fullpath}{path}/" title="{name}">
						<xsl:value-of disable-output-escaping="yes" select="name"/>
					</a>
				</p>

				<p>
					<!-- Цена -->
					<b>
						<xsl:value-of disable-output-escaping="yes" select="price_discount"/>&#xA0;<xsl:value-of disable-output-escaping="yes" select="currency"/>&#xA0;</b>

					<!-- Ссылку на добавление в корзины выводим, если:
					type = 0 - простой тип товара
					type = 1 - электронный товар, при этом остаток на складе больше 0 или -1,
					что означает неограниченное количество -->
					<xsl:if test="type = 0 or (type = 1 and (eitem_count &gt; 0 or eitem_count = -1))">
						<a href="{/shop/path}cart/?action=add&amp;item_id={@id}" onclick="return AddIntoCart('{/shop/path}', {@id}, 1)">
							<img alt="В корзину" title="В корзину" src="/hostcmsfiles/images/cart.gif"/>
						</a>
					</xsl:if>
				</p>
			</div>
		</div>

		<xsl:if test="position() mod 2 = 0 and position() != last()">
			<div class="clearing"></div>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet><!-- Stylus Studio meta-information - (c) 2004-2009. Progress Software Corporation. All rights reserved.

<metaInformation>
	<scenarios>
		<scenario default="yes" name="Scenario1" userelativepaths="yes" externalpreview="no" url="310.xml" htmlbaseurl="" outputurl="" processortype="internal" useresolver="yes" profilemode="0" profiledepth="" profilelength="" urlprofilexml=""
		          commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext="" validateoutput="no" validator="internal" customvalidator=""/>
	</scenarios>
	<MapperMetaTag>
		<MapperInfo srcSchemaPathIsRelative="yes" srcSchemaInterpretAsXML="no" destSchemaPath="" destSchemaRoot="" destSchemaPathIsRelative="yes" destSchemaInterpretAsXML="no"/>
		<MapperBlockPosition></MapperBlockPosition>
		<TemplateContext></TemplateContext>
		<MapperFilter side="source"></MapperFilter>
	</MapperMetaTag>
</metaInformation>
-->